;; Generated package description from aircon-theme.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "aircon-theme" "0.0.6.0.20260507.72645" "Cool and legible light theme" '((emacs "24.4")) :commit "f645680681a50507d7541739aec6afdff5116da7" :authors '(("Gregory Chamberlain" . "greg@cosine.blue")) :maintainer '("Gregory Chamberlain" . "~chambln/public-inbox@lists.sr.ht") :keywords '("faces") :url "https://git.sr.ht/~chambln/aircon-theme.el")
